package Autorepo::Config;

use strict;
use warnings;
use Carp;
use Getopt::Long;

our $VERSION=0.010;

require Exporter;
our @ISA = qw(Exporter);

our @EXPORT = qw(
$AUTOREPO_ROOT $AUTOREPO_SHARED_SRPMS $AUTOREPO_BRANCH %CONFIG
@AUTOREPO_RPM_DIRS @AUTOREPO_RPM_LINKDIRS @AUTOREPO_SRPM_LINKDIRS
);
our @EXPORT_OK = qw(@AUTOREPO_ARCH);

push @EXPORT_OK, @EXPORT;

our ($AUTOREPO_BRANCH, $AUTOREPO_SHARED_SRPMS, @AUTOREPO_ARCH, $AUTOREPO_ROOT);
our (@AUTOREPO_RPM_DIRS,@AUTOREPO_RPM_LINKDIRS,@AUTOREPO_SRPM_LINKDIRS);
our %CONFIG;

my $fn;
if (not open ($fn, '-|', 'autorepo-print-unquoted-environment')) {
    if ($ENV{'RPM_BUILD_DIR'}) {
	#warn "$!: failed to run autorepo-print-unquoted-environment. Assuming buildroot\n";
	return 1;
    } else {
	die "$!: failed to run autorepo-print-unquoted-environment\n";
    }
} else {
    while(<$fn>) {
	chomp;
	if (/^([\w\d_]+)=(.*)/) {
	    $CONFIG{$1}=$2;
	} else {
	    warn "Oops! unreadable config: $_";
	}
    }
    close($fn);
    die 'autorepo-print-unquoted-environment failed' if ${^CHILD_ERROR_NATIVE};

    $AUTOREPO_BRANCH=$CONFIG{'AUTOREPO_BRANCH'};
    $AUTOREPO_SHARED_SRPMS=$CONFIG{'AUTOREPO_SHARED_SRPMS'};
    @AUTOREPO_ARCH=split(/\s+/,$CONFIG{'GB_ARCH'});
    my $_noarch=$CONFIG{'GB_NOARCH'};
    unshift @AUTOREPO_ARCH, $_noarch if $_noarch;
    $AUTOREPO_ROOT=$CONFIG{'AUTOREPO_ROOT'};

    my @component_names=split(/\s+/,$CONFIG{'GB_REPO_COMPONENT_NAMES'});
    my @srpm_component_names;
    if ($CONFIG{'AUTOREPO_SRPM_COMPONENT_NAMES'}) {
	@srpm_component_names=split(/\s+/,$CONFIG{'AUTOREPO_SRPM_COMPONENT_NAMES'});
    } else {
	@srpm_component_names=@component_names unless @srpm_component_names;
    }
    foreach my $arch (@AUTOREPO_ARCH) {
	foreach my $component_name (@component_names) {
	    push @AUTOREPO_RPM_DIRS, "$AUTOREPO_ROOT/$arch/RPMS.$component_name";
	}
	foreach my $component_name (@srpm_component_names) {
	    push @AUTOREPO_SRPM_LINKDIRS, "$AUTOREPO_ROOT/$arch/SRPMS.$component_name";
	}
    }

    die "Initialization failed. Bad AUTOREPO_ROOT or AUTOREPO_SHARED_SRPMS or GB_REPO_COMPONENT_NAMES.
run autorepo-print-unquoted-environment to check variables." unless $AUTOREPO_ROOT and $AUTOREPO_SHARED_SRPMS and @component_names;

    die "Initialization failed. AUTOREPO_PURGE_DESTPATH should be set to the path(s) to the main repository(ies) or to 'none' if we build the main repository here." unless $CONFIG{'AUTOREPO_PURGE_DESTPATH'};
}

1;
